@@ -2,21 +2,23 @@
 # SPDX-License-Identifier: Apache-2.0
 
 import logging
+from typing import Any, List
 
-from pyhocon import ConfigTree, ConfigFactory  # noqa: F401
-from typing import Any  # noqa: F401
+from pyhocon import ConfigFactory, ConfigTree
 
 from databuilder import Scoped
 from databuilder.extractor.base_extractor import Extractor
 from databuilder.extractor.dashboard.mode_analytics.mode_dashboard_utils import ModeDashboardUtils
 from databuilder.rest_api.mode_analytics.mode_paginated_rest_api_query import ModePaginatedRestApiQuery
 from databuilder.rest_api.rest_api_query import RestApiQuery
-from databuilder.transformer.base_transformer import ChainedTransformer
-from databuilder.transformer.dict_to_model import DictToModel, MODEL_CLASS
-from databuilder.transformer.regex_str_replace_transformer import RegexStrReplaceTransformer, \
-    REGEX_REPLACE_TUPLE_LIST, ATTRIBUTE_NAME
-from databuilder.transformer.template_variable_substitution_transformer import \
-    TemplateVariableSubstitutionTransformer, TEMPLATE, FIELD_NAME
+from databuilder.transformer.base_transformer import ChainedTransformer, Transformer
+from databuilder.transformer.dict_to_model import MODEL_CLASS, DictToModel
+from databuilder.transformer.regex_str_replace_transformer import (
+    ATTRIBUTE_NAME, REGEX_REPLACE_TUPLE_LIST, RegexStrReplaceTransformer,
+)
+from databuilder.transformer.template_variable_substitution_transformer import (
+    FIELD_NAME, TEMPLATE, TemplateVariableSubstitutionTransformer,
+)
 
 LOGGER = logging.getLogger(__name__)
 
@@ -27,8 +29,7 @@ class ModeDashboardQueriesExtractor(Extractor):
 
     """
 
-    def init(self, conf):
-        # type: (ConfigTree) -> None
+    def init(self, conf: ConfigTree) -> None:
         self._conf = conf
 
         restapi_query = self._build_restapi_query()
@@ -38,7 +39,7 @@ class ModeDashboardQueriesExtractor(Extractor):
         )
 
         # Constructing URL using several ID via TemplateVariableSubstitutionTransformer
-        transformers = []
+        transformers: List[Transformer] = []
         variable_substitution_transformer = TemplateVariableSubstitutionTransformer()
         variable_substitution_transformer.init(
             conf=Scoped.get_scoped_conf(self._conf,
@@ -66,26 +67,22 @@ class ModeDashboardQueriesExtractor(Extractor):
 
         self._transformer = ChainedTransformer(transformers=transformers)
 
-    def extract(self):
-        # type: () -> Any
-
+    def extract(self) -> Any:
         record = self._extractor.extract()
         if not record:
             return None
 
         return self._transformer.transform(record=record)
 
-    def get_scope(self):
-        # type: () -> str
+    def get_scope(self) -> str:
         return 'extractor.mode_dashboard_query'
 
-    def _build_restapi_query(self):
+    def _build_restapi_query(self) -> RestApiQuery:
         """
         Build REST API Query. To get Mode Dashboard last execution, it needs to call three APIs (spaces API, reports
         API, and queries API) joining together.
         :return: A RestApiQuery that provides Mode Dashboard execution (run)
         """
-        # type: () -> RestApiQuery
 
         spaces_query = ModeDashboardUtils.get_spaces_query_api(conf=self._conf)
         params = ModeDashboardUtils.get_auth_params(conf=self._conf)
